models.rpmodel – Random Projections — gensim documentation

### Navigation

- index
- modules |
- next |
- previous |
- home|
- search|
- documentation »
- API Reference »

# `models.rpmodel` – Random Projections

class `gensim.models.rpmodel.` `RpModel`(corpus, id2word=None, numTopics=300)

  Objects of this class allow building and maintaining a model for Random Projections (also known as Random Indexing). For theoretical background on RP, see:

  > Kanerva et al.: “Random indexing of text samples for Latent Semantic Analysis.”

  The main methods are:

  1. constructor, which creates the random projection matrix
  2. the [] method, which transforms a simple count representation into the TfIdf space.

      >>> rp = RpModel(corpus)
      >>> print rp[some_doc]
      >>> rp.save('/tmp/foo.rp_model')

  Model persistency is achieved via its load/save methods.

  id2word is a mapping from word ids (integers) to words (strings). It is used to determine the vocabulary size, as well as for debugging and topic printing. If not set, it will be determined from the corpus.

  `initialize`(corpus)
    Initialize the random projection matrix.
  classmethod `load`(fname)
    Load a previously saved object from file (also see save).
  `save`(fname)
    Save the object to file via pickling (also see load).

### Navigation

- index
- modules |
- next |
- previous |
- home|
- search|
- documentation »
- API Reference »